summaryrefslogtreecommitdiffstats
path: root/chalk/core/kis_paintop_registry.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /chalk/core/kis_paintop_registry.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'chalk/core/kis_paintop_registry.h')
-rw-r--r--chalk/core/kis_paintop_registry.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chalk/core/kis_paintop_registry.h b/chalk/core/kis_paintop_registry.h
index c61105b6..338b9f01 100644
--- a/chalk/core/kis_paintop_registry.h
+++ b/chalk/core/kis_paintop_registry.h
@@ -56,10 +56,10 @@ public:
/**
* Create and return an (abstracted) configuration widget
* for using the specified paintop with the specified input device,
* with the specified tqparent as widget tqparent. Returns 0 if there
* are no settings available for the given device.
*/
- KisPaintOpSettings * settings(const KisID& id, TQWidget * tqparent, const KisInputDevice& inputDevice) const;
+ KisPaintOpSettings * settings(const KisID& id, TQWidget * parent, const KisInputDevice& inputDevice) const;
// Whether we should show this paintop in the toolchest
bool userVisible(const KisID & id, KisColorSpace* cs) const;
@@ -56,10 +56,10 @@ public:
* Create and return an (abstracted) configuration widget
* for using the specified paintop with the specified input device,
- * with the specified tqparent as widget tqparent. Returns 0 if there
+ * with the specified parent as widget parent. Returns 0 if there
* are no settings available for the given device.
*/